summaryrefslogtreecommitdiffstats
path: root/twin
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2025-01-14 15:08:54 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2025-01-14 15:08:54 +0900
commit5fc09cf26e477474a1e166c9c8262c789be3a0fa (patch)
tree64772d38380dd5fc4a08efc43a7ac15bd20e6558 /twin
parentb8f5a7414bd00abef13ef3ef6557f742849b9191 (diff)
downloadtdebase-5fc09cf26e477474a1e166c9c8262c789be3a0fa.tar.gz
tdebase-5fc09cf26e477474a1e166c9c8262c789be3a0fa.zip
Use tdeApp
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'twin')
-rw-r--r--twin/clients/PORTING2
-rw-r--r--twin/clients/modernsystem/config/config.cpp2
-rw-r--r--twin/geometry.cpp10
-rw-r--r--twin/kcmtwin/twindecoration/twindecoration.cpp2
-rw-r--r--twin/kcmtwin/twinoptions/main.cpp12
-rw-r--r--twin/kcmtwin/twinoptions/mouse.cpp14
-rw-r--r--twin/kcmtwin/twinoptions/windows.cpp34
-rw-r--r--twin/kcmtwin/twinrules/kcm.cpp6
-rw-r--r--twin/kcmtwin/twinrules/main.cpp6
-rw-r--r--twin/lib/kdecoration.h2
-rw-r--r--twin/sm.cpp8
-rw-r--r--twin/tools/decobenchmark/preview.cpp8
-rw-r--r--twin/useractions.cpp4
-rw-r--r--twin/workspace.cpp30
14 files changed, 70 insertions, 70 deletions
diff --git a/twin/clients/PORTING b/twin/clients/PORTING
index 199ddb9de..3db8af576 100644
--- a/twin/clients/PORTING
+++ b/twin/clients/PORTING
@@ -84,7 +84,7 @@ inline const KDecorationOptions* options() { return KDecoration::options(); }
- Replace 'contextHelp()' with 'showContextHelp()'.
- WindowWrapperShowEvent() is gone, simply use showEvent() filtered by the event filter if needed.
- Change 'animateIconifyOrDeiconify()' to 'animateMinize()', if it's empty, simply remove it.
- Make sure it doesn't reenter the event loop (no kapp->processEvents()).
+ Make sure it doesn't reenter the event loop (no tdeApp->processEvents()).
- Buttons should use explicit setCursor() if they don't want cursor set by mousePosition().
I.e. usually call setCursor( ArrowCursor ) in your MyButton.
- In the part where you insert windowWrapper() into the layout, i.e. something like
diff --git a/twin/clients/modernsystem/config/config.cpp b/twin/clients/modernsystem/config/config.cpp
index 4fba7538d..c353abc1b 100644
--- a/twin/clients/modernsystem/config/config.cpp
+++ b/twin/clients/modernsystem/config/config.cpp
@@ -57,7 +57,7 @@ ModernSysConfig::ModernSysConfig(TDEConfig* conf, TQWidget* parent) : TQObject(p
hbox = new TQHBox(sliderBox);
hbox->setSpacing(6);
- bool rtl = kapp->reverseLayout();
+ bool rtl = tdeApp->reverseLayout();
label1 = new TQLabel(i18n("Small"), hbox);
label1->setAlignment(rtl ? AlignRight : AlignLeft);
label2 = new TQLabel(i18n("Medium"), hbox);
diff --git a/twin/geometry.cpp b/twin/geometry.cpp
index 581c07ac1..657c6a1ed 100644
--- a/twin/geometry.cpp
+++ b/twin/geometry.cpp
@@ -223,12 +223,12 @@ TQRect Workspace::clientArea( clientAreaOption opt, int screen, int desktop ) co
{
if( desktop == NETWinInfo::OnAllDesktops || desktop == 0 )
desktop = currentDesktop();
- TQDesktopWidget *desktopwidget = kapp->desktop();
+ TQDesktopWidget *desktopwidget = tdeApp->desktop();
TQRect sarea = screenarea // may be NULL during KWin initialization
? screenarea[ desktop ][ screen ]
: desktopwidget->screenGeometry( screen );
TQRect warea = workarea[ desktop ].isNull()
- ? kapp->desktop()->geometry()
+ ? tdeApp->desktop()->geometry()
: workarea[ desktop ];
switch (opt)
{
@@ -802,7 +802,7 @@ TQRect Client::adjustedClientArea( const TQRect &desktopArea, const TQRect& area
// HACK: workarea handling is not xinerama aware, so if this strut
// reserves place at a xinerama edge that's inside the virtual screen,
// ignore the strut for workspace setting.
- if( area == kapp->desktop()->geometry())
+ if( area == tdeApp->desktop()->geometry())
{
if( stareaL.left() < screenarea.left())
stareaL = TQRect();
@@ -2376,14 +2376,14 @@ bool Client::startMoveResize()
|| ( isResize() && rules()->checkMoveResizeMode( options->resizeMode ) != Options::Opaque ) )
{
grabXServer();
- kapp->sendPostedEvents();
+ tdeApp->sendPostedEvents();
// we have server grab -> nothing should cause paint events
// unfortunately, that's not completely true, Qt may generate
// paint events on some widgets due to FocusIn(?)
// eat them, otherwise XOR painting will be broken (#58054)
// paint events for the geometrytip need to be allowed, though
// eater = new EatAllPaintEvents;
-// not needed anymore? kapp->installEventFilter( eater );
+// not needed anymore? tdeApp->installEventFilter( eater );
}
Notify::raise( isResize() ? Notify::ResizeStart : Notify::MoveStart );
diff --git a/twin/kcmtwin/twindecoration/twindecoration.cpp b/twin/kcmtwin/twindecoration/twindecoration.cpp
index 3050bdf36..a1de82d0a 100644
--- a/twin/kcmtwin/twindecoration/twindecoration.cpp
+++ b/twin/kcmtwin/twindecoration/twindecoration.cpp
@@ -970,7 +970,7 @@ TQString KWinDecorationModule::handbookSection() const
void KWinDecorationModule::resetKWin()
{
- bool ok = kapp->dcopClient()->send("twin*", "KWinInterface",
+ bool ok = tdeApp->dcopClient()->send("twin*", "KWinInterface",
"reconfigure()", TQByteArray());
if (!ok)
kdDebug() << "kcmtwindecoration: Could not reconfigure twin" << endl;
diff --git a/twin/kcmtwin/twinoptions/main.cpp b/twin/kcmtwin/twinoptions/main.cpp
index 0b392cd14..0bc9c942c 100644
--- a/twin/kcmtwin/twinoptions/main.cpp
+++ b/twin/kcmtwin/twinoptions/main.cpp
@@ -183,9 +183,9 @@ void KWinOptions::save()
emit TDECModule::changed( false );
// Send signal to twin
mConfig->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
@@ -295,9 +295,9 @@ void TDEActionsOptions::save()
emit TDECModule::changed( false );
// Send signal to twin
mConfig->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
diff --git a/twin/kcmtwin/twinoptions/mouse.cpp b/twin/kcmtwin/twinoptions/mouse.cpp
index 0e197071c..8ed44e79e 100644
--- a/twin/kcmtwin/twinoptions/mouse.cpp
+++ b/twin/kcmtwin/twinoptions/mouse.cpp
@@ -368,7 +368,7 @@ KTitleBarActionsConfig::KTitleBarActionsConfig (bool _standAlone, TDEConfig *_co
coMax[b]->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum ));
}
- connect(kapp, TQ_SIGNAL(tdedisplayPaletteChanged()), TQ_SLOT(paletteChanged()));
+ connect(tdeApp, TQ_SIGNAL(tdedisplayPaletteChanged()), TQ_SLOT(paletteChanged()));
layout->addStretch();
@@ -567,9 +567,9 @@ void KTitleBarActionsConfig::save()
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
}
@@ -850,9 +850,9 @@ void KWindowActionsConfig::save()
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
}
diff --git a/twin/kcmtwin/twinoptions/windows.cpp b/twin/kcmtwin/twinoptions/windows.cpp
index e88601507..fae19516f 100644
--- a/twin/kcmtwin/twinoptions/windows.cpp
+++ b/twin/kcmtwin/twinoptions/windows.cpp
@@ -585,9 +585,9 @@ void KFocusConfig::save( void )
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
emit TDECModule::changed(false);
}
@@ -748,9 +748,9 @@ void KActiveBorderConfig::save() {
if (standAlone)
{
config->sync();
- if (!kapp->dcopClient()->isAttached())
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if (!tdeApp->dcopClient()->isAttached())
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
emit TDECModule::changed(false);
}
@@ -954,9 +954,9 @@ void KAdvancedConfig::save( void )
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
emit TDECModule::changed(false);
}
@@ -1382,9 +1382,9 @@ void KMovingConfig::save( void )
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
emit TDECModule::changed(false);
}
@@ -1965,9 +1965,9 @@ void KTranslucencyConfig::save( void )
if (standAlone)
{
config->sync();
- if ( !kapp->dcopClient()->isAttached() )
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if ( !tdeApp->dcopClient()->isAttached() )
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
if (useTranslucency->isChecked())
startKompmgr();
@@ -2035,12 +2035,12 @@ bool KTranslucencyConfig::kompmgrAvailable()
void KTranslucencyConfig::startKompmgr()
{
- kapp->dcopClient()->send("twin*", "", "startKompmgr()", TQString(""));
+ tdeApp->dcopClient()->send("twin*", "", "startKompmgr()", TQString(""));
}
void KTranslucencyConfig::stopKompmgr()
{
- kapp->dcopClient()->send("twin*", "", "stopKompmgr()", TQString(""));
+ tdeApp->dcopClient()->send("twin*", "", "stopKompmgr()", TQString(""));
}
void KTranslucencyConfig::showWarning(bool alphaActivated)
diff --git a/twin/kcmtwin/twinrules/kcm.cpp b/twin/kcmtwin/twinrules/kcm.cpp
index e2a75ee62..7e2cac86c 100644
--- a/twin/kcmtwin/twinrules/kcm.cpp
+++ b/twin/kcmtwin/twinrules/kcm.cpp
@@ -66,9 +66,9 @@ void KCMRules::save()
emit TDECModule::changed( false );
// Send signal to twin
config.sync();
- if( !kapp->dcopClient()->isAttached())
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if( !tdeApp->dcopClient()->isAttached())
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
}
void KCMRules::defaults()
diff --git a/twin/kcmtwin/twinrules/main.cpp b/twin/kcmtwin/twinrules/main.cpp
index 67e21332c..ef8a30956 100644
--- a/twin/kcmtwin/twinrules/main.cpp
+++ b/twin/kcmtwin/twinrules/main.cpp
@@ -256,9 +256,9 @@ static int edit( Window wid, bool whole_app )
delete orig_rule;
}
saveRules( rules );
- if( !kapp->dcopClient()->isAttached())
- kapp->dcopClient()->attach();
- kapp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
+ if( !tdeApp->dcopClient()->isAttached())
+ tdeApp->dcopClient()->attach();
+ tdeApp->dcopClient()->send("twin*", "", "reconfigure()", TQString(""));
return 0;
}
diff --git a/twin/lib/kdecoration.h b/twin/lib/kdecoration.h
index ee8e66eef..03daebc28 100644
--- a/twin/lib/kdecoration.h
+++ b/twin/lib/kdecoration.h
@@ -659,7 +659,7 @@ class KWIN_EXPORT KDecoration
* This function may be reimplemented to provide custom minimize/restore animations
* The reimplementation is allowed to perform X server grabs if necessary
* (only using the functions provided by this API, no direct Xlib calls), but no
- * futher event processing is allowed (i.e. no kapp->processEvents()).
+ * futher event processing is allowed (i.e. no tdeApp->processEvents()).
* @a False should be returned if the default implementation should be used.
* Note that you should not use this function to force disabling of the animation.
*
diff --git a/twin/sm.cpp b/twin/sm.cpp
index 00cdb6a22..0b51dd284 100644
--- a/twin/sm.cpp
+++ b/twin/sm.cpp
@@ -42,13 +42,13 @@ bool SessionManaged::saveState( TQSessionManager& sm )
{
Workspace::self()->sessionSaveStarted();
if( ksmserver ) // save stacking order etc. before "save file?" etc. dialogs change it
- Workspace::self()->storeSession( kapp->sessionConfig(), SMSavePhase0 );
+ Workspace::self()->storeSession( tdeApp->sessionConfig(), SMSavePhase0 );
sm.release(); // Qt doesn't automatically release in this case (bug?)
sm.requestPhase2();
return true;
}
- Workspace::self()->storeSession( kapp->sessionConfig(), ksmserver ? SMSavePhase2 : SMSavePhase2Full );
- kapp->sessionConfig()->sync();
+ Workspace::self()->storeSession( tdeApp->sessionConfig(), ksmserver ? SMSavePhase2 : SMSavePhase2Full );
+ tdeApp->sessionConfig()->sync();
return true;
}
@@ -149,7 +149,7 @@ void Workspace::storeSession( TDEConfig* config, SMSavePhase phase )
void Workspace::loadSessionInfo()
{
session.clear();
- TDEConfig* config = kapp->sessionConfig();
+ TDEConfig* config = tdeApp->sessionConfig();
config->setGroup("Session" );
int count = config->readNumEntry( "count" );
int active_client = config->readNumEntry( "active" );
diff --git a/twin/tools/decobenchmark/preview.cpp b/twin/tools/decobenchmark/preview.cpp
index c706eb5df..33ee8fd3e 100644
--- a/twin/tools/decobenchmark/preview.cpp
+++ b/twin/tools/decobenchmark/preview.cpp
@@ -67,7 +67,7 @@ void KDecorationPreview::performRepaintTest(int n)
positionPreviews(0);
for (int i = 0; i < n; ++i) {
deco->widget()->repaint();
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
@@ -80,7 +80,7 @@ void KDecorationPreview::performCaptionTest(int n)
bridge->setCaption(caption.arg(i) );
deco->captionChange();
deco->widget()->repaint();
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
@@ -91,7 +91,7 @@ void KDecorationPreview::performResizeTest(int n)
deco->captionChange();
for (int i = 0; i < n; ++i) {
positionPreviews(i % 200);
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
@@ -103,7 +103,7 @@ void KDecorationPreview::performRecreationTest(int n)
positionPreviews(0);
for (int i = 0; i < n; ++i) {
recreateDecoration();
- kapp->processEvents();
+ tdeApp->processEvents();
}
}
diff --git a/twin/useractions.cpp b/twin/useractions.cpp
index 821828e19..c50c77401 100644
--- a/twin/useractions.cpp
+++ b/twin/useractions.cpp
@@ -131,7 +131,7 @@ TQPopupMenu* Workspace::clientPopup()
popup->insertSeparator();
if (!TDEGlobal::config()->isImmutable() &&
- !kapp->authorizeControlModules(Workspace::configModules(true)).isEmpty())
+ !tdeApp->authorizeControlModules(Workspace::configModules(true)).isEmpty())
{
popup->insertItem(SmallIconSet( "configure" ), i18n("Configur&e Window Behavior…"), this, TQ_SLOT( configureWM() ));
popup->insertSeparator();
@@ -1148,7 +1148,7 @@ void Workspace::slotWindowOperations()
void Workspace::showWindowMenu( const TQRect &pos, Client* cl )
{
- if (!kapp->authorizeTDEAction("twin_rmb"))
+ if (!tdeApp->authorizeTDEAction("twin_rmb"))
return;
if( !cl )
return;
diff --git a/twin/workspace.cpp b/twin/workspace.cpp
index b710b6579..d942adfe6 100644
--- a/twin/workspace.cpp
+++ b/twin/workspace.cpp
@@ -220,7 +220,7 @@ Workspace::Workspace( bool restore )
(WFlags)(TQt::WType_Desktop | TQt::WPaintUnclipped)
);
- kapp->setGlobalMouseTracking( true ); // so that this doesn't mess eventmask on root window later
+ tdeApp->setGlobalMouseTracking( true ); // so that this doesn't mess eventmask on root window later
// call this before XSelectInput() on the root window
startup = new TDEStartupInfo(
TDEStartupInfo::DisableKWinModule | TDEStartupInfo::AnnounceSilenceChanges, this );
@@ -259,7 +259,7 @@ Workspace::Workspace( bool restore )
init();
#if (TQT_VERSION-0 >= 0x030200) // XRANDR support
- connect( kapp->desktop(), TQ_SIGNAL( resized( int )), TQ_SLOT( desktopResized()));
+ connect( tdeApp->desktop(), TQ_SIGNAL( resized( int )), TQ_SLOT( desktopResized()));
#endif
if (!supportsCompMgr()) {
@@ -414,12 +414,12 @@ void Workspace::init()
// extra NETRootInfo instance in Client mode is needed to get the values of the properties
NETRootInfo client_info( tqt_xdisplay(), NET::ActiveWindow | NET::CurrentDesktop );
int initial_desktop;
- if( !kapp->isSessionRestored())
+ if( !tdeApp->isSessionRestored())
initial_desktop = client_info.currentDesktop();
else
{
- TDEConfigGroupSaver saver( kapp->sessionConfig(), "Session" );
- initial_desktop = kapp->sessionConfig()->readNumEntry( "desktop", 1 );
+ TDEConfigGroupSaver saver( tdeApp->sessionConfig(), "Session" );
+ initial_desktop = tdeApp->sessionConfig()->readNumEntry( "desktop", 1 );
}
if( !setCurrentDesktop( initial_desktop ))
setCurrentDesktop( 1 );
@@ -431,16 +431,16 @@ void Workspace::init()
TQ_SLOT(slotReconfigure()));
connect( &updateToolWindowsTimer, TQ_SIGNAL( timeout()), this, TQ_SLOT( slotUpdateToolWindows()));
- connect(kapp, TQ_SIGNAL(appearanceChanged()), this,
+ connect(tdeApp, TQ_SIGNAL(appearanceChanged()), this,
TQ_SLOT(slotReconfigure()));
- connect(kapp, TQ_SIGNAL(settingsChanged(int)), this,
+ connect(tdeApp, TQ_SIGNAL(settingsChanged(int)), this,
TQ_SLOT(slotSettingsChanged(int)));
- connect(kapp, TQ_SIGNAL( kipcMessage( int, int )), this, TQ_SLOT( kipcMessage( int, int )));
+ connect(tdeApp, TQ_SIGNAL( kipcMessage( int, int )), this, TQ_SLOT( kipcMessage( int, int )));
active_client = NULL;
rootInfo->setActiveWindow( None );
focusToNull();
- if( !kapp->isSessionRestored())
+ if( !tdeApp->isSessionRestored())
++block_focus; // because it will be set below
char nm[ 100 ];
@@ -503,7 +503,7 @@ void Workspace::init()
} // end updates blocker block
Client* new_active_client = NULL;
- if( !kapp->isSessionRestored())
+ if( !tdeApp->isSessionRestored())
{
--block_focus;
new_active_client = findClient( WindowMatchPredicate( client_info.activeWindow()));
@@ -1277,7 +1277,7 @@ TQStringList Workspace::configModules(bool controlCenter)
args << "tde-twindecoration.desktop";
if (controlCenter)
args << "tde-twinoptions.desktop";
- else if (kapp->authorizeControlModule("tde-twinoptions.desktop"))
+ else if (tdeApp->authorizeControlModule("tde-twinoptions.desktop"))
args << "twinactions" << "twinfocus" << "twinmoving" << "twinadvanced" << "twinrules" << "twintranslucency";
return args;
}
@@ -1423,7 +1423,7 @@ bool Workspace::setCurrentDesktop( int new_desktop )
current_desktop = new_desktop; // change the desktop (so that Client::updateVisibility() works)
- bool desktopHasCompositing = kapp->isCompositionManagerAvailable(); // Technically I should call isX11CompositionAvailable(), but it isn't initialized via my kapp constructir, and in this case it doesn't really matter anyway....
+ bool desktopHasCompositing = tdeApp->isCompositionManagerAvailable(); // Technically I should call isX11CompositionAvailable(), but it isn't initialized via my tdeApp constructir, and in this case it doesn't really matter anyway....
if (!desktopHasCompositing) {
// If composition is not in use then we can hide the old windows before showing the new ones
for ( ClientList::ConstIterator it = stacking_order.begin(); it != stacking_order.end(); ++it) {
@@ -1806,7 +1806,7 @@ void Workspace::setActiveScreenMouse( TQPoint mousepos )
TQRect Workspace::screenGeometry( int screen ) const
{
- if (( !options->xineramaEnabled ) || (kapp->desktop()->numScreens() < 2))
+ if (( !options->xineramaEnabled ) || (tdeApp->desktop()->numScreens() < 2))
return tqApp->desktop()->geometry();
return tqApp->desktop()->screenGeometry( screen );
}
@@ -2995,7 +2995,7 @@ void Workspace::startKompmgr()
TQByteArray ba;
TQDataStream arg(ba, IO_WriteOnly);
arg << "";
- kapp->dcopClient()->emitDCOPSignal("default", "kompmgrStarted()", ba);
+ tdeApp->dcopClient()->emitDCOPSignal("default", "kompmgrStarted()", ba);
}
if (popup){ delete popup; popup = 0L; } // to add/remove opacity slider
}
@@ -3014,7 +3014,7 @@ void Workspace::stopKompmgr()
TQByteArray ba;
TQDataStream arg(ba, IO_WriteOnly);
arg << "";
- kapp->dcopClient()->emitDCOPSignal("default", "kompmgrStopped()", ba);
+ tdeApp->dcopClient()->emitDCOPSignal("default", "kompmgrStopped()", ba);
}
void Workspace::kompmgrReloadSettings()